@@ -23,22 +23,22 @@ class Vector3:
 
 class Pose:
 
-    def __init__(self, position: Vector3, orientation: Vector3, name: str = '', _type: str = ''):
+    def __init__(self, position: Vector3, rotation: Vector3, name: str = '', _type: str = ''):
         self._type = 'pose'
         self.name = name
         self.position = position
-        self.orientation = orientation
+        self.rotation = rotation
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Pose):
-            return other.name == self.name and other.position == self.position and other.orientation == self.orientation
+            return other.name == self.name and other.position == self.position and other.rotation == self.rotation
         return False
 
     def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
 
     def __repr__(self):
-        return f"Pose<name={self.name}, position={self.position}, orientation={self.orientation}>"
+        return f"Pose<name={self.name}, position={self.position}, orientation={self.rotation}>"
 
 
 class Poses:
