@@ -10,8 +10,8 @@ class Test(TestCase):
         operation = Operation('uuid_1', 'product_1', {'x': 0.0, 'y': 0.0, 'z': 0.0, 'rx': 0.0, 'ry': 0.0, 'rz': 0.0})
         operation_string = json_encode(operation)
         expected_string = '{"_type": "operation", "uuid": "uuid_1", "product_uuid": "product_1", ' \
-                          '"pose": {"x": 0.0, "y": 0.0, "z": 0.0, "rx": 0.0, "ry": 0.0, "rz": 0.0}, "automated": false,' \
-                          ' "description": ""}'
+                          '"pose": {"x": 0.0, "y": 0.0, "z": 0.0, "rx": 0.0, "ry": 0.0, "rz": 0.0}, ' \
+                          '"automated": false, "confirm_needed": false, "description": ""}'
 
         assert type(operation_string) == str
         assert operation_string == expected_string, f"Expected {expected_string}, got: {operation_string}"
